This is the Code Window, where you'll write the programs (the "code") that brings your projects to life!

On the left side, you'll see line numbers — these are a handy if you need to refer to a specific line of code.

The PLAY button runs your code. While your code is running, the PLAY button will change from a triangle to a square — and you can press the square to stop your code.

The OPEN button allows you to open another program that you previously wrote, or create a brand new one.

It also allows you to change the name of your programs, or delete programs you don't want anymore.

The SAVE button saves your current program.

Don't worry, though. Programs are saved automatically every now and then, just in case you forget.

The SETTINGS button allows you to change the look of the RDE, update the software, and more...

This is name of the current program being edited.

To the left of the name is the Ready Set STEM logo — it will spin when a program is running. On the right, you'll see a double arrow, which allows you to expand the Code Window to the full screen.

This is the Program Output window.

When you run your program, sometimes it will "print" some information, for example, the result of a calculation. Whatever the program prints will be displayed here.

Also, if there's an error in the program, the error will be displayed here.

The BACK button works just like a back button in a web browser — it allows you to go to the previous page in the Projects Guide.

Similarly, the FORWARD button works just like a forward button in a web browser — it allows you to return to a page after you've gone back.

The HOME button brings you to the Projects Guide index.

For advanced users:

The API button brings you to the API (Application Programming Interface) documentation. The API provides functions for accessing the hardware on the Ready Set STEM CREATOR Kit.

In addition, all further buttons bring you to other documentation — for example, the Python programming language documentation.

# INTRODUCTION TO THE RDE

If you're reading this, you've successfully built your Ready Set STEM CREATOR Kit, connected it to a monitor and powered it on. You're now viewing the Ready Set STEM Development Environment (RDE), where you'll learn how to create electronics hardware and write code!

The first thing you'll likely notice is that the screen is split down the middle, with the left side in blue and the right side in white (you're probably reading this on the right-hand side of the screen right now). You'll write and run your own code on the left side, while following the Projects Guide on the right side.

But, the easiest way to get an idea of how this works, is to take the tour:

Now that you have a basic overview of the RDE, it's time to write and run your first program.

To start working on the first project, click the next link below...